# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from datetime import datetime
from datetime import timedelta
from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from protobuf_to_pydantic.util import Timedelta
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
import typing



class KnownRegex(IntEnum):
    UNKNOWN = 0
    HTTP_HEADER_NAME = 1
    HTTP_HEADER_VALUE = 2




class FieldRules(BaseModel):

    _one_of_dict = {"FieldRules.type": {"fields": {"any", "bool", "bytes", "double", "duration", "enum", "fixed32", "fixed64", "float", "int32", "int64", "map", "repeated", "sfixed32", "sfixed64", "sint32", "sint64", "string", "timestamp", "uint32", "uint64"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    message: MessageRules = FieldInfo() 
    float: FloatRules = FieldInfo() 
    double: DoubleRules = FieldInfo() 
    int32: Int32Rules = FieldInfo() 
    int64: Int64Rules = FieldInfo() 
    uint32: UInt32Rules = FieldInfo() 
    uint64: UInt64Rules = FieldInfo() 
    sint32: SInt32Rules = FieldInfo() 
    sint64: SInt64Rules = FieldInfo() 
    fixed32: Fixed32Rules = FieldInfo() 
    fixed64: Fixed64Rules = FieldInfo() 
    sfixed32: SFixed32Rules = FieldInfo() 
    sfixed64: SFixed64Rules = FieldInfo() 
    bool: BoolRules = FieldInfo() 
    string: StringRules = FieldInfo() 
    bytes: BytesRules = FieldInfo() 
    enum: EnumRules = FieldInfo() 
    repeated: RepeatedRules = FieldInfo() 
    map: MapRules = FieldInfo() 
    any: AnyRules = FieldInfo() 
    duration: DurationRules = FieldInfo() 
    timestamp: TimestampRules = FieldInfo() 




class FloatRules(BaseModel):

    const: float = FieldInfo(default=0.0) 
    lt: float = FieldInfo(default=0.0) 
    lte: float = FieldInfo(default=0.0) 
    gt: float = FieldInfo(default=0.0) 
    gte: float = FieldInfo(default=0.0) 
    not_in: typing.List[float] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class DoubleRules(BaseModel):

    const: float = FieldInfo(default=0.0) 
    lt: float = FieldInfo(default=0.0) 
    lte: float = FieldInfo(default=0.0) 
    gt: float = FieldInfo(default=0.0) 
    gte: float = FieldInfo(default=0.0) 
    not_in: typing.List[float] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class Int32Rules(BaseModel):

    const: int = FieldInfo(default=0) 
    lt: int = FieldInfo(default=0) 
    lte: int = FieldInfo(default=0) 
    gt: int = FieldInfo(default=0) 
    gte: int = FieldInfo(default=0) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class Int64Rules(BaseModel):

    const: int = FieldInfo(default=0) 
    lt: int = FieldInfo(default=0) 
    lte: int = FieldInfo(default=0) 
    gt: int = FieldInfo(default=0) 
    gte: int = FieldInfo(default=0) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class UInt32Rules(BaseModel):

    const: int = FieldInfo(default=0) 
    lt: int = FieldInfo(default=0) 
    lte: int = FieldInfo(default=0) 
    gt: int = FieldInfo(default=0) 
    gte: int = FieldInfo(default=0) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class UInt64Rules(BaseModel):

    const: int = FieldInfo(default=0) 
    lt: int = FieldInfo(default=0) 
    lte: int = FieldInfo(default=0) 
    gt: int = FieldInfo(default=0) 
    gte: int = FieldInfo(default=0) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class SInt32Rules(BaseModel):

    const: int = FieldInfo(default=0) 
    lt: int = FieldInfo(default=0) 
    lte: int = FieldInfo(default=0) 
    gt: int = FieldInfo(default=0) 
    gte: int = FieldInfo(default=0) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class SInt64Rules(BaseModel):

    const: int = FieldInfo(default=0) 
    lt: int = FieldInfo(default=0) 
    lte: int = FieldInfo(default=0) 
    gt: int = FieldInfo(default=0) 
    gte: int = FieldInfo(default=0) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class Fixed32Rules(BaseModel):

    const: float = FieldInfo(default=0.0) 
    lt: float = FieldInfo(default=0.0) 
    lte: float = FieldInfo(default=0.0) 
    gt: float = FieldInfo(default=0.0) 
    gte: float = FieldInfo(default=0.0) 
    not_in: typing.List[float] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class Fixed64Rules(BaseModel):

    const: float = FieldInfo(default=0.0) 
    lt: float = FieldInfo(default=0.0) 
    lte: float = FieldInfo(default=0.0) 
    gt: float = FieldInfo(default=0.0) 
    gte: float = FieldInfo(default=0.0) 
    not_in: typing.List[float] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class SFixed32Rules(BaseModel):

    const: float = FieldInfo(default=0.0) 
    lt: float = FieldInfo(default=0.0) 
    lte: float = FieldInfo(default=0.0) 
    gt: float = FieldInfo(default=0.0) 
    gte: float = FieldInfo(default=0.0) 
    not_in: typing.List[float] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class SFixed64Rules(BaseModel):

    const: float = FieldInfo(default=0.0) 
    lt: float = FieldInfo(default=0.0) 
    lte: float = FieldInfo(default=0.0) 
    gt: float = FieldInfo(default=0.0) 
    gte: float = FieldInfo(default=0.0) 
    not_in: typing.List[float] = FieldInfo(default_factory=list) 
    ignore_empty: bool = FieldInfo(default=False) 




class BoolRules(BaseModel):

    const: bool = FieldInfo(default=False) 




class StringRules(BaseModel):

    _one_of_dict = {"StringRules.well_known": {"fields": {"address", "email", "hostname", "ip", "ipv4", "ipv6", "uri", "uri_ref", "uuid", "well_known_regex"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    const: str = FieldInfo(default="") 
    len: int = FieldInfo(default=0) 
    min_len: int = FieldInfo(default=0) 
    max_len: int = FieldInfo(default=0) 
    len_bytes: int = FieldInfo(default=0) 
    min_bytes: int = FieldInfo(default=0) 
    max_bytes: int = FieldInfo(default=0) 
    pattern: str = FieldInfo(default="") 
    prefix: str = FieldInfo(default="") 
    suffix: str = FieldInfo(default="") 
    contains: str = FieldInfo(default="") 
    not_contains: str = FieldInfo(default="") 
    not_in: typing.List[str] = FieldInfo(default_factory=list) 
    email: bool = FieldInfo(default=False) 
    hostname: bool = FieldInfo(default=False) 
    ip: bool = FieldInfo(default=False) 
    ipv4: bool = FieldInfo(default=False) 
    ipv6: bool = FieldInfo(default=False) 
    uri: bool = FieldInfo(default=False) 
    uri_ref: bool = FieldInfo(default=False) 
    address: bool = FieldInfo(default=False) 
    uuid: bool = FieldInfo(default=False) 
    well_known_regex: KnownRegex = FieldInfo(default=0) 
    strict: bool = FieldInfo(default=False) 
    ignore_empty: bool = FieldInfo(default=False) 




class BytesRules(BaseModel):

    _one_of_dict = {"BytesRules.well_known": {"fields": {"ip", "ipv4", "ipv6"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    const: bytes = FieldInfo(default=b"") 
    len: int = FieldInfo(default=0) 
    min_len: int = FieldInfo(default=0) 
    max_len: int = FieldInfo(default=0) 
    pattern: str = FieldInfo(default="") 
    prefix: bytes = FieldInfo(default=b"") 
    suffix: bytes = FieldInfo(default=b"") 
    contains: bytes = FieldInfo(default=b"") 
    not_in: typing.List[bytes] = FieldInfo(default_factory=list) 
    ip: bool = FieldInfo(default=False) 
    ipv4: bool = FieldInfo(default=False) 
    ipv6: bool = FieldInfo(default=False) 
    ignore_empty: bool = FieldInfo(default=False) 




class EnumRules(BaseModel):

    const: int = FieldInfo(default=0) 
    defined_only: bool = FieldInfo(default=False) 
    not_in: typing.List[int] = FieldInfo(default_factory=list) 




class MessageRules(BaseModel):

    skip: bool = FieldInfo(default=False) 
    required: bool = FieldInfo(default=False) 




class RepeatedRules(BaseModel):

    min_items: int = FieldInfo(default=0) 
    max_items: int = FieldInfo(default=0) 
    unique: bool = FieldInfo(default=False) 
    items: FieldRules = FieldInfo() 
    ignore_empty: bool = FieldInfo(default=False) 




class MapRules(BaseModel):

    min_pairs: int = FieldInfo(default=0) 
    max_pairs: int = FieldInfo(default=0) 
    no_sparse: bool = FieldInfo(default=False) 
    keys: FieldRules = FieldInfo() 
    values: FieldRules = FieldInfo() 
    ignore_empty: bool = FieldInfo(default=False) 




class AnyRules(BaseModel):

    required: bool = FieldInfo(default=False) 
    not_in: typing.List[str] = FieldInfo(default_factory=list) 




class DurationRules(BaseModel):

    required: bool = FieldInfo(default=False) 
    const: Timedelta = FieldInfo(default_factory=timedelta) 
    lt: Timedelta = FieldInfo(default_factory=timedelta) 
    lte: Timedelta = FieldInfo(default_factory=timedelta) 
    gt: Timedelta = FieldInfo(default_factory=timedelta) 
    gte: Timedelta = FieldInfo(default_factory=timedelta) 
    not_in: typing.List[Timedelta] = FieldInfo(default_factory=list) 




class TimestampRules(BaseModel):

    required: bool = FieldInfo(default=False) 
    const: datetime = FieldInfo(default_factory=datetime.now) 
    lt: datetime = FieldInfo(default_factory=datetime.now) 
    lte: datetime = FieldInfo(default_factory=datetime.now) 
    gt: datetime = FieldInfo(default_factory=datetime.now) 
    gte: datetime = FieldInfo(default_factory=datetime.now) 
    lt_now: bool = FieldInfo(default=False) 
    gt_now: bool = FieldInfo(default=False) 
    within: Timedelta = FieldInfo(default_factory=timedelta) 





# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo





class CreditTransaction(BaseModel):

    _one_of_dict = {"CreditTransaction._credit": {"fields": {"credit"}}, "CreditTransaction._credit_dollar": {"fields": {"credit_dollar"}}, "CreditTransaction._date_extract": {"fields": {"date_extract"}}, "CreditTransaction._meta_1": {"fields": {"meta_1"}}, "CreditTransaction._meta_1_desc": {"fields": {"meta_1_desc"}}, "CreditTransaction._meta_2": {"fields": {"meta_2"}}, "CreditTransaction._meta_2_desc": {"fields": {"meta_2_desc"}}, "CreditTransaction._meta_3": {"fields": {"meta_3"}}, "CreditTransaction._meta_3_desc": {"fields": {"meta_3_desc"}}, "CreditTransaction._plan": {"fields": {"plan"}}, "CreditTransaction._quantity": {"fields": {"quantity"}}, "CreditTransaction._scenario": {"fields": {"scenario"}}, "CreditTransaction._type": {"fields": {"type"}}, "CreditTransaction._unit": {"fields": {"unit"}}, "CreditTransaction._unit_price": {"fields": {"unit_price"}}, "CreditTransaction._user": {"fields": {"user"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    scenario: str = FieldInfo(default="") 
    user: str = FieldInfo(default="") 
    plan: str = FieldInfo(default="") 
    type: str = FieldInfo(default="") 
    meta_1_desc: str = FieldInfo(default="") 
    meta_1: str = FieldInfo(default="") 
    meta_2_desc: str = FieldInfo(default="") 
    meta_2: str = FieldInfo(default="") 
    meta_3_desc: str = FieldInfo(default="") 
    meta_3: str = FieldInfo(default="") 
    quantity: float = FieldInfo(default=0.0) 
    unit: str = FieldInfo(default="") 
    unit_price: float = FieldInfo(default=0.0) 
    credit: float = FieldInfo(default=0.0) 
    credit_dollar: float = FieldInfo(default=0.0) 
    date_extract: str = FieldInfo(default="") 




class Balance(BaseModel):

    _one_of_dict = {"Balance._balance": {"fields": {"balance"}}, "Balance._balance_dollar": {"fields": {"balance_dollar"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    balance: float = FieldInfo(default=0.0) 
    balance_dollar: float = FieldInfo(default=0.0) 





# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from pydantic import BaseModel
from pydantic import root_validator
from pydantic.fields import FieldInfo
import typing



class SecretError(IntEnum):
    SECRET_NO_ERROR = 0
    SECRET_ALREADY_EXISTS = 1
    SECRET_NOT_FOUND = 2
    SECRET_MARKED_FOR_DELETION = 3




class Secret(BaseModel):

    _one_of_dict = {"Secret._name": {"fields": {"name"}}, "Secret._value": {"fields": {"value"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 
    value: str = FieldInfo(default="") 




class SecretResponseError(BaseModel):

    _one_of_dict = {"SecretResponseError._error": {"fields": {"error"}}, "SecretResponseError._message": {"fields": {"message"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: SecretError = FieldInfo(default=0) 
    message: str = FieldInfo(default="") 




class SecretCreateRequest(BaseModel):

    _one_of_dict = {"SecretCreateRequest._secret": {"fields": {"secret"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    secret: Secret = FieldInfo() 




class SecretCreateResponse(BaseModel):

    _one_of_dict = {"SecretCreateResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: SecretResponseError = FieldInfo() 




class SecretGetRequest(BaseModel):

    _one_of_dict = {"SecretGetRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 




class SecretGetResponse(BaseModel):

    _one_of_dict = {"SecretGetResponse._error": {"fields": {"error"}}, "SecretGetResponse._secret": {"fields": {"secret"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    secret: Secret = FieldInfo() 
    error: SecretResponseError = FieldInfo() 




class SecretDeleteRequest(BaseModel):

    _one_of_dict = {"SecretDeleteRequest._name": {"fields": {"name"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 




class SecretDeleteResponse(BaseModel):

    _one_of_dict = {"SecretDeleteResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: SecretResponseError = FieldInfo() 




class SecretListRequest(BaseModel):

    _one_of_dict = {"SecretListRequest._page_number": {"fields": {"page_number"}}, "SecretListRequest._page_size": {"fields": {"page_size"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    page_size: int = FieldInfo(default=0) 
    page_number: int = FieldInfo(default=0) 




class SecretListResponse(BaseModel):

    _one_of_dict = {"SecretListResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    secrets: typing.List[Secret] = FieldInfo(default_factory=list) 
    error: SecretResponseError = FieldInfo() 





# This is an automatically generated file, please do not change
# gen by protobuf_to_pydantic(https://github.com/so1n/protobuf_to_pydantic)
# type: ignore

from enum import IntEnum
from google.protobuf.message import Message  # type: ignore
from protobuf_to_pydantic.customer_validator import check_one_of
from protobuf_to_pydantic.customer_validator import in_validator
from pydantic import BaseModel
from pydantic import root_validator
from pydantic import validator
from pydantic.fields import FieldInfo
from uuid import UUID
import typing



class WorkspaceError(IntEnum):
    WORKSPACE_NO_ERROR = 0
    WORKSPACE_NOT_FOUND = 1
    WORKSPACE_USER_ALREADY_EXISTS = 2
    WORKSPACE_USER_NOT_FOUND = 3
    WORKSPACE_USER_ALREADY_ACTIVE = 4
    USER_ALREADY_HAVE_PERSONAL_WORKSPACE = 5
    WORKSPACE_PLUGIN_NOT_FOUND = 6
    INTERNAL_SERVER_ERROR = 1000




class Workspace(BaseModel):

    _one_of_dict = {"Workspace._create_at": {"fields": {"create_at"}}, "Workspace._id": {"fields": {"id"}}, "Workspace._is_personal": {"fields": {"is_personal"}}, "Workspace._logo": {"fields": {"logo"}}, "Workspace._name": {"fields": {"name"}}, "Workspace._primary_color": {"fields": {"primary_color"}}, "Workspace._secondary_color": {"fields": {"secondary_color"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: UUID = FieldInfo(default="") 
    name: str = FieldInfo(default="") 
    logo: str = FieldInfo(default="") 
    primary_color: str = FieldInfo(default="") 
    secondary_color: str = FieldInfo(default="") 
    is_personal: bool = FieldInfo(default=False) 
    create_at: str = FieldInfo(default="") 




class WorkspaceUpdate(BaseModel):

    _one_of_dict = {"WorkspaceUpdate._logo": {"fields": {"logo"}}, "WorkspaceUpdate._name": {"fields": {"name"}}, "WorkspaceUpdate._primary_color": {"fields": {"primary_color"}}, "WorkspaceUpdate._secondary_color": {"fields": {"secondary_color"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    name: str = FieldInfo(default="") 
    logo: str = FieldInfo(default="") 
    primary_color: str = FieldInfo(default="") 
    secondary_color: str = FieldInfo(default="") 




class WorkspaceUser(BaseModel):

    role_in_validator = validator("role",  allow_reuse=True)(in_validator)
    status_in_validator = validator("status",  allow_reuse=True)(in_validator)
    _one_of_dict = {"WorkspaceUser._create_at": {"fields": {"create_at"}}, "WorkspaceUser._role": {"fields": {"role"}}, "WorkspaceUser._status": {"fields": {"status"}}, "WorkspaceUser._update_at": {"fields": {"update_at"}}, "WorkspaceUser._user_id": {"fields": {"user_id"}}, "WorkspaceUser._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 
    role: str = FieldInfo(default="", in_=["admin", "member", "owner"]) 
    status: str = FieldInfo(default="", in_=["active", "declined", "invited"]) 
    create_at: str = FieldInfo(default="") 
    update_at: str = FieldInfo(default="") 




class WorkspaceUserUpdate(BaseModel):

    role_in_validator = validator("role",  allow_reuse=True)(in_validator)
    status_in_validator = validator("status",  allow_reuse=True)(in_validator)
    _one_of_dict = {"WorkspaceUserUpdate._role": {"fields": {"role"}}, "WorkspaceUserUpdate._status": {"fields": {"status"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    role: str = FieldInfo(default="", in_=["admin", "member", "owner"]) 
    status: str = FieldInfo(default="", in_=["active", "declined", "invited"]) 




class WorkspacePlugin(BaseModel):

    _one_of_dict = {"WorkspacePlugin._create_at": {"fields": {"create_at"}}, "WorkspacePlugin._id": {"fields": {"id"}}, "WorkspacePlugin._payload": {"fields": {"payload"}}, "WorkspacePlugin._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 
    payload: str = FieldInfo(default="") 
    create_at: str = FieldInfo(default="") 




class WorkspacePluginUpdate(BaseModel):

    _one_of_dict = {"WorkspacePluginUpdate._payload": {"fields": {"payload"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    payload: str = FieldInfo(default="") 




class WorkspaceResponseError(BaseModel):

    _one_of_dict = {"WorkspaceResponseError._code": {"fields": {"code"}}, "WorkspaceResponseError._message": {"fields": {"message"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    code: WorkspaceError = FieldInfo(default=0) 
    message: str = FieldInfo(default="") 




class WorkspaceListRequest(BaseModel):

    _one_of_dict = {"WorkspaceListRequest._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 




class WorkspaceListResponse(BaseModel):

    _one_of_dict = {"WorkspaceListResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspaces: typing.List[Workspace] = FieldInfo(default_factory=list) 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceCreateRequest(BaseModel):

    _one_of_dict = {"WorkspaceCreateRequest._is_personal": {"fields": {"is_personal"}}, "WorkspaceCreateRequest._logo": {"fields": {"logo"}}, "WorkspaceCreateRequest._name": {"fields": {"name"}}, "WorkspaceCreateRequest._primary_color": {"fields": {"primary_color"}}, "WorkspaceCreateRequest._secondary_color": {"fields": {"secondary_color"}}, "WorkspaceCreateRequest._user_id": {"fields": {"user_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    name: str = FieldInfo(default="") 
    logo: str = FieldInfo(default="") 
    primary_color: str = FieldInfo(default="") 
    secondary_color: str = FieldInfo(default="") 
    is_personal: bool = FieldInfo(default=False) 




class WorkspaceCreateResponse(BaseModel):

    _one_of_dict = {"WorkspaceCreateResponse._error": {"fields": {"error"}}, "WorkspaceCreateResponse._workspace": {"fields": {"workspace"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace: Workspace = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceGetRequest(BaseModel):

    _one_of_dict = {"WorkspaceGetRequest._user_id": {"fields": {"user_id"}}, "WorkspaceGetRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 




class WorkspaceGetResponse(BaseModel):

    _one_of_dict = {"WorkspaceGetResponse._error": {"fields": {"error"}}, "WorkspaceGetResponse._workspace": {"fields": {"workspace"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace: Workspace = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceUpdateRequest(BaseModel):

    _one_of_dict = {"WorkspaceUpdateRequest._workspace": {"fields": {"workspace"}}, "WorkspaceUpdateRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 
    workspace: WorkspaceUpdate = FieldInfo() 




class WorkspaceUpdateResponse(BaseModel):

    _one_of_dict = {"WorkspaceUpdateResponse._error": {"fields": {"error"}}, "WorkspaceUpdateResponse._workspace": {"fields": {"workspace"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace: Workspace = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceDeleteRequest(BaseModel):

    _one_of_dict = {"WorkspaceDeleteRequest._user_id": {"fields": {"user_id"}}, "WorkspaceDeleteRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 




class WorkspaceDeleteResponse(BaseModel):

    _one_of_dict = {"WorkspaceDeleteResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceUserListRequest(BaseModel):

    _one_of_dict = {"WorkspaceUserListRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 




class WorkspaceUserListResponse(BaseModel):

    _one_of_dict = {"WorkspaceUserListResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_users: typing.List[WorkspaceUser] = FieldInfo(default_factory=list) 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceUserGetRequest(BaseModel):

    _one_of_dict = {"WorkspaceUserGetRequest._user_id": {"fields": {"user_id"}}, "WorkspaceUserGetRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 




class WorkspaceUserGetResponse(BaseModel):

    _one_of_dict = {"WorkspaceUserGetResponse._error": {"fields": {"error"}}, "WorkspaceUserGetResponse._workspace_user": {"fields": {"workspace_user"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_user: WorkspaceUser = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceUserUpdateRequest(BaseModel):

    _one_of_dict = {"WorkspaceUserUpdateRequest._user_id": {"fields": {"user_id"}}, "WorkspaceUserUpdateRequest._workspace_id": {"fields": {"workspace_id"}}, "WorkspaceUserUpdateRequest._workspace_user": {"fields": {"workspace_user"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 
    workspace_user: WorkspaceUserUpdate = FieldInfo() 




class WorkspaceUserUpdateResponse(BaseModel):

    _one_of_dict = {"WorkspaceUserUpdateResponse._error": {"fields": {"error"}}, "WorkspaceUserUpdateResponse._workspace_user": {"fields": {"workspace_user"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_user: WorkspaceUser = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspaceUserDeleteRequest(BaseModel):

    _one_of_dict = {"WorkspaceUserDeleteRequest._user_id": {"fields": {"user_id"}}, "WorkspaceUserDeleteRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    user_id: UUID = FieldInfo(default="") 
    workspace_id: UUID = FieldInfo(default="") 




class WorkspaceUserDeleteResponse(BaseModel):

    _one_of_dict = {"WorkspaceUserDeleteResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: WorkspaceResponseError = FieldInfo() 




class WorkspacePluginCreateRequest(BaseModel):

    _one_of_dict = {"WorkspacePluginCreateRequest._payload": {"fields": {"payload"}}, "WorkspacePluginCreateRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 
    payload: str = FieldInfo(default="") 




class WorkspacePluginCreateResponse(BaseModel):

    _one_of_dict = {"WorkspacePluginCreateResponse._error": {"fields": {"error"}}, "WorkspacePluginCreateResponse._workspace_plugin": {"fields": {"workspace_plugin"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_plugin: WorkspacePlugin = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspacePluginGetRequest(BaseModel):

    _one_of_dict = {"WorkspacePluginGetRequest._plugin_id": {"fields": {"plugin_id"}}, "WorkspacePluginGetRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 
    plugin_id: UUID = FieldInfo(default="") 




class WorkspacePluginGetResponse(BaseModel):

    _one_of_dict = {"WorkspacePluginGetResponse._error": {"fields": {"error"}}, "WorkspacePluginGetResponse._workspace_plugin": {"fields": {"workspace_plugin"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_plugin: WorkspacePlugin = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspacePluginListRequest(BaseModel):

    _one_of_dict = {"WorkspacePluginListRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 




class WorkspacePluginListResponse(BaseModel):

    _one_of_dict = {"WorkspacePluginListResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_plugins: typing.List[WorkspacePlugin] = FieldInfo(default_factory=list) 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspacePluginUpdateRequest(BaseModel):

    _one_of_dict = {"WorkspacePluginUpdateRequest._plugin_id": {"fields": {"plugin_id"}}, "WorkspacePluginUpdateRequest._workspace_id": {"fields": {"workspace_id"}}, "WorkspacePluginUpdateRequest._workspace_plugin": {"fields": {"workspace_plugin"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 
    plugin_id: UUID = FieldInfo(default="") 
    workspace_plugin: WorkspacePluginUpdate = FieldInfo() 




class WorkspacePluginUpdateResponse(BaseModel):

    _one_of_dict = {"WorkspacePluginUpdateResponse._error": {"fields": {"error"}}, "WorkspacePluginUpdateResponse._workspace_plugin": {"fields": {"workspace_plugin"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_plugin: WorkspacePlugin = FieldInfo() 
    error: WorkspaceResponseError = FieldInfo() 




class WorkspacePluginDeleteRequest(BaseModel):

    _one_of_dict = {"WorkspacePluginDeleteRequest._plugin_id": {"fields": {"plugin_id"}}, "WorkspacePluginDeleteRequest._workspace_id": {"fields": {"workspace_id"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    workspace_id: UUID = FieldInfo(default="") 
    plugin_id: UUID = FieldInfo(default="") 




class WorkspacePluginDeleteResponse(BaseModel):

    _one_of_dict = {"WorkspacePluginDeleteResponse._error": {"fields": {"error"}}}
    _check_one_of = root_validator(pre=True, allow_reuse=True)(check_one_of)

    error: WorkspaceResponseError = FieldInfo() 





# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: chat.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import enum_type_wrapper
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import struct_pb2 as google_dot_protobuf_dot_struct__pb2
import naas_models.validate_pb2 as validate__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nchat.proto\x12\x04\x63hat\x1a\x1cgoogle/protobuf/struct.proto\x1a\x0evalidate.proto\"\xa8\x01\n\x14MessageResponseError\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.chat.MessageErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xd4\x04\n\x07Message\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12!\n\ncreated_at\x18\x03 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x02\x88\x01\x01\x12\x14\n\x07\x63hat_id\x18\x04 \x01(\x05H\x03\x88\x01\x01\x12\x16\n\tfrom_user\x18\x05 \x01(\x08H\x04\x88\x01\x01\x12\x14\n\x07message\x18\x06 \x01(\tH\x05\x88\x01\x01\x12#\n\x0cmessage_type\x18\x07 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x06\x88\x01\x01\x12\'\n\x10message_language\x18\x08 \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x07\x88\x01\x01\x12\x15\n\x08model_id\x18\t \x01(\tH\x08\x88\x01\x01\x12$\n\x04type\x18\n \x01(\x0e\x32\x11.chat.MessageTypeH\t\x88\x01\x01\x12\x15\n\x08metadata\x18\x0b \x01(\tH\n\x88\x01\x01\x12!\n\ndeleted_at\x18\x0c \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\x0b\x88\x01\x01\x12\x15\n\x08selected\x18\r \x01(\x08H\x0c\x88\x01\x01\x12\"\n\x0b\x61rchived_at\x18\x0e \x01(\tB\x08\xfa\x42\x05r\x03\xd0\x01\x01H\r\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_versionB\r\n\x0b_created_atB\n\n\x08_chat_idB\x0c\n\n_from_userB\n\n\x08_messageB\x0f\n\r_message_typeB\x13\n\x11_message_languageB\x0b\n\t_model_idB\x07\n\x05_typeB\x0b\n\t_metadataB\r\n\x0b_deleted_atB\x0b\n\t_selectedB\x0e\n\x0c_archived_at\"+\n\x08Messages\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\"R\n\x16MessageDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x05\n\x03_idB\n\n\x08_version\"K\n\x17MessageDeletionResponse\x12&\n\x05\x65rror\x18\x01 \x01(\x0e\x32\x12.chat.MessageErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\xad\x01\n\x19MessageRatinResponseError\x12%\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x12.chat.MessageErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"\xef\x01\n\rMessageRating\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x14\n\x07user_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x03 \x01(\x05H\x02\x88\x01\x01\x12\x17\n\ncreated_at\x18\x04 \x01(\tH\x03\x88\x01\x01\x12/\n\x06rating\x18\x05 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x04\x88\x01\x01\x42\r\n\x0b_message_idB\n\n\x08_user_idB\x12\n\x10_message_versionB\r\n\x0b_created_atB\t\n\x07_rating\"\xb4\x01\n\x1cMessageRatingCreationRequest\x12\x17\n\nmessage_id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x1c\n\x0fmessage_version\x18\x02 \x01(\x05H\x01\x88\x01\x01\x12/\n\x06rating\x18\x03 \x01(\tB\x1a\xfa\x42\x17r\x15\x32\x10^(LIKE|DISLIKE)$\xd0\x01\x00H\x02\x88\x01\x01\x42\r\n\x0b_message_idB\x12\n\x10_message_versionB\t\n\x07_rating\"\xa3\x01\n\x1dMessageRatingCreationResponse\x12\x33\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x1f.chat.MessageRatinResponseErrorH\x00\x88\x01\x01\x12\x30\n\x0emessage_rating\x18\x02 \x01(\x0b\x32\x13.chat.MessageRatingH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x11\n\x0f_message_rating\"\xb6\x02\n\x04\x43hat\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x17\n\ncreated_at\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07user_id\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x11\n\x04name\x18\x04 \x01(\tH\x03\x88\x01\x01\x12\x17\n\ndeleted_at\x18\x05 \x01(\tH\x04\x88\x01\x01\x12\x15\n\x08is_group\x18\x06 \x01(\x08H\x05\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x07 \x01(\x08H\x06\x88\x01\x01\x12\x17\n\nstarred_at\x18\x08 \x01(\tH\x07\x88\x01\x01\x42\x05\n\x03_idB\r\n\x0b_created_atB\n\n\x08_user_idB\x07\n\x05_nameB\r\n\x0b_deleted_atB\x0b\n\t_is_groupB\x18\n\x16_is_personal_assistantB\r\n\x0b_starred_at\"\x83\x01\n\x0c\x43hatMessages\x12\x32\n\x08messages\x18\x01 \x03(\x0b\x32 .chat.ChatMessages.MessagesEntry\x1a?\n\rMessagesEntry\x12\x0b\n\x03key\x18\x01 \x01(\x05\x12\x1d\n\x05value\x18\x02 \x01(\x0b\x32\x0e.chat.Messages:\x02\x38\x01\"\xa2\x01\n\x11\x43hatResponseError\x12\"\n\x04\x63ode\x18\x01 \x01(\x0e\x32\x0f.chat.ChatErrorH\x00\x88\x01\x01\x12\x13\n\x06status\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06reason\x18\x03 \x01(\tH\x02\x88\x01\x01\x12\x14\n\x07message\x18\x04 \x01(\tH\x03\x88\x01\x01\x42\x07\n\x05_codeB\t\n\x07_statusB\t\n\x07_reasonB\n\n\x08_message\"o\n\x13\x43hatCreationRequest\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\"\n\x15is_personal_assistant\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x07\n\x05_nameB\x18\n\x16_is_personal_assistant\"u\n\x14\x43hatCreationResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"(\n\x0e\x43hatGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"p\n\x0f\x43hatGetResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"/\n\x15\x43hatMessageGetRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"\x87\x01\n\x16\x43hatMessageGetResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x12)\n\x08messages\x18\x02 \x01(\x0b\x32\x12.chat.ChatMessagesH\x01\x88\x01\x01\x42\x08\n\x06_errorB\x0b\n\t_messages\"-\n\x13\x43hatDeletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x42\x05\n\x03_id\"M\n\x14\x43hatDeletionResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"G\n\x11\x43hatUpdateRequest\x12\x0f\n\x02id\x18\x01 \x01(\x03H\x00\x88\x01\x01\x12\x11\n\x04name\x18\x02 \x01(\tH\x01\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_name\"s\n\x12\x43hatUpdateResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x08\n\x06_error\"a\n\x0f\x43hatListRequest\x12\x16\n\tpage_size\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x18\n\x0bpage_number\x18\x02 \x01(\x05H\x01\x88\x01\x01\x42\x0c\n\n_page_sizeB\x0e\n\x0c_page_number\"c\n\x10\x43hatListResponse\x12\x18\n\x04\x63hat\x18\x01 \x03(\x0b\x32\n.chat.Chat\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"E\n\x0f\x43hatStarRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x11\n\x04star\x18\x02 \x01(\x08H\x01\x88\x01\x01\x42\x05\n\x03_idB\x07\n\x05_star\"g\n\x10\x43hatStarResponse\x12\x1d\n\x04\x63hat\x18\x01 \x01(\x0b\x32\n.chat.ChatH\x00\x88\x01\x01\x12\"\n\x04\x63ode\x18\x02 \x01(\x0e\x32\x0f.chat.ChatErrorH\x01\x88\x01\x01\x42\x07\n\x05_chatB\x07\n\x05_code\"\xa5\x02\n\x12\x43ompletionResponse\x12\x1f\n\x08messages\x18\x01 \x03(\x0b\x32\r.chat.Message\x12\x19\n\x0cinput_tokens\x18\x02 \x01(\x05H\x00\x88\x01\x01\x12\x1a\n\routput_tokens\x18\x03 \x01(\x05H\x01\x88\x01\x01\x12\x1d\n\x10image_resolution\x18\x04 \x01(\tH\x02\x88\x01\x01\x12\x18\n\x0bimage_steps\x18\x05 \x01(\x05H\x03\x88\x01\x01\x12+\n\x06status\x18\x06 \x01(\x0e\x32\x16.chat.CompletionStatusH\x04\x88\x01\x01\x42\x0f\n\r_input_tokensB\x10\n\x0e_output_tokensB\x13\n\x11_image_resolutionB\x0e\n\x0c_image_stepsB\t\n\x07_status\"c\n\x0b\x42\x61sePayload\x12\x11\n\x04name\x18\x01 \x01(\tH\x00\x88\x01\x01\x12\x10\n\x03url\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x13\n\x06prompt\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x07\n\x05_nameB\x06\n\x04_urlB\t\n\x07_prompt\"u\n\x15\x43hatCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x12\x15\n\x08model_id\x18\x02 \x01(\tH\x01\x88\x01\x01\x12\x14\n\x07payload\x18\x03 \x01(\tH\x02\x88\x01\x01\x42\x05\n\x03_idB\x0b\n\t_model_idB\n\n\x08_payload\"3\n\x19\x43hatStopCompletionRequest\x12\x0f\n\x02id\x18\x01 \x01(\x05H\x00\x88\x01\x01\x42\x05\n\x03_id\"S\n\x1a\x43hatStopCompletionResponse\x12+\n\x05\x65rror\x18\x01 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x00\x88\x01\x01\x42\x08\n\x06_error\"\x91\x01\n\x16\x43hatCompletionResponse\x12\x31\n\ncompletion\x18\x01 \x01(\x0b\x32\x18.chat.CompletionResponseH\x00\x88\x01\x01\x12+\n\x05\x65rror\x18\x02 \x01(\x0b\x32\x17.chat.ChatResponseErrorH\x01\x88\x01\x01\x42\r\n\x0b_completionB\x08\n\x06_error*;\n\x0bMessageType\x12\r\n\tUNDEFINED\x10\x00\x12\n\n\x06SYSTEM\x10\x01\x12\x06\n\x02\x41I\x10\x02\x12\t\n\x05HUMAN\x10\x03*\x8c\x01\n\x0cMessageError\x12\x14\n\x10MESSAGE_NO_ERROR\x10\x00\x12\x1a\n\x16MESSAGE_ALREADY_EXISTS\x10\x01\x12\x15\n\x11MESSAGE_NOT_FOUND\x10\x02\x12\x17\n\x13MESSAGE_NOT_UPDATED\x10\x03\x12\x1a\n\x16MESSAGE_NOT_AUTHORIZED\x10\x04*:\n\x10\x43ompletionStatus\x12\r\n\tCOMPLETED\x10\x00\x12\n\n\x06\x46\x41ILED\x10\x01\x12\x0b\n\x07TIMEOUT\x10\x02*\xfd\x01\n\tChatError\x12\x11\n\rCHAT_NO_ERROR\x10\x00\x12\x17\n\x13\x43HAT_ALREADY_EXISTS\x10\x01\x12\x12\n\x0e\x43HAT_NOT_FOUND\x10\x02\x12\x14\n\x10\x43HAT_NOT_UPDATED\x10\x03\x12\x17\n\x13\x43HAT_NOT_AUTHORIZED\x10\x04\x12+\n\'CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXISTS\x10\x05\x12\x1a\n\x16\x43HAT_AIMODEL_NOT_FOUND\x10\x06\x12\x16\n\x12\x43HAT_OUT_OF_CREDIT\x10\x07\x12 \n\x1c\x43HAT_CONTEXT_LENGTH_EXCEEDED\x10\x08\x32\xfa\x02\n\x0b\x43hatService\x12\x41\n\x06\x43reate\x12\x19.chat.ChatCreationRequest\x1a\x1a.chat.ChatCreationResponse\"\x00\x12\x34\n\x03Get\x12\x14.chat.ChatGetRequest\x1a\x15.chat.ChatGetResponse\"\x00\x12\x37\n\x04List\x12\x15.chat.ChatListRequest\x1a\x16.chat.ChatListResponse\"\x00\x12\x41\n\x06\x44\x65lete\x12\x19.chat.ChatDeletionRequest\x1a\x1a.chat.ChatDeletionResponse\"\x00\x12=\n\x06Update\x12\x17.chat.ChatUpdateRequest\x1a\x18.chat.ChatUpdateResponse\"\x00\x12\x37\n\x04Star\x12\x15.chat.ChatStarRequest\x1a\x16.chat.ChatStarResponse\"\x00\x42-Z+github.com/jupyter-naas/naas-models/go/chatb\x06proto3')

_MESSAGETYPE = DESCRIPTOR.enum_types_by_name['MessageType']
MessageType = enum_type_wrapper.EnumTypeWrapper(_MESSAGETYPE)
_MESSAGEERROR = DESCRIPTOR.enum_types_by_name['MessageError']
MessageError = enum_type_wrapper.EnumTypeWrapper(_MESSAGEERROR)
_COMPLETIONSTATUS = DESCRIPTOR.enum_types_by_name['CompletionStatus']
CompletionStatus = enum_type_wrapper.EnumTypeWrapper(_COMPLETIONSTATUS)
_CHATERROR = DESCRIPTOR.enum_types_by_name['ChatError']
ChatError = enum_type_wrapper.EnumTypeWrapper(_CHATERROR)
UNDEFINED = 0
SYSTEM = 1
AI = 2
HUMAN = 3
MESSAGE_NO_ERROR = 0
MESSAGE_ALREADY_EXISTS = 1
MESSAGE_NOT_FOUND = 2
MESSAGE_NOT_UPDATED = 3
MESSAGE_NOT_AUTHORIZED = 4
COMPLETED = 0
FAILED = 1
TIMEOUT = 2
CHAT_NO_ERROR = 0
CHAT_ALREADY_EXISTS = 1
CHAT_NOT_FOUND = 2
CHAT_NOT_UPDATED = 3
CHAT_NOT_AUTHORIZED = 4
CHAT_COMPLETION_ADAPTOR_DOES_NOT_EXISTS = 5
CHAT_AIMODEL_NOT_FOUND = 6
CHAT_OUT_OF_CREDIT = 7
CHAT_CONTEXT_LENGTH_EXCEEDED = 8


_MESSAGERESPONSEERROR = DESCRIPTOR.message_types_by_name['MessageResponseError']
_MESSAGE = DESCRIPTOR.message_types_by_name['Message']
_MESSAGES = DESCRIPTOR.message_types_by_name['Messages']
_MESSAGEDELETIONREQUEST = DESCRIPTOR.message_types_by_name['MessageDeletionRequest']
_MESSAGEDELETIONRESPONSE = DESCRIPTOR.message_types_by_name['MessageDeletionResponse']
_MESSAGERATINRESPONSEERROR = DESCRIPTOR.message_types_by_name['MessageRatinResponseError']
_MESSAGERATING = DESCRIPTOR.message_types_by_name['MessageRating']
_MESSAGERATINGCREATIONREQUEST = DESCRIPTOR.message_types_by_name['MessageRatingCreationRequest']
_MESSAGERATINGCREATIONRESPONSE = DESCRIPTOR.message_types_by_name['MessageRatingCreationResponse']
_CHAT = DESCRIPTOR.message_types_by_name['Chat']
_CHATMESSAGES = DESCRIPTOR.message_types_by_name['ChatMessages']
_CHATMESSAGES_MESSAGESENTRY = _CHATMESSAGES.nested_types_by_name['MessagesEntry']
_CHATRESPONSEERROR = DESCRIPTOR.message_types_by_name['ChatResponseError']
_CHATCREATIONREQUEST = DESCRIPTOR.message_types_by_name['ChatCreationRequest']
_CHATCREATIONRESPONSE = DESCRIPTOR.message_types_by_name['ChatCreationResponse']
_CHATGETREQUEST = DESCRIPTOR.message_types_by_name['ChatGetRequest']
_CHATGETRESPONSE = DESCRIPTOR.message_types_by_name['ChatGetResponse']
_CHATMESSAGEGETREQUEST = DESCRIPTOR.message_types_by_name['ChatMessageGetRequest']
_CHATMESSAGEGETRESPONSE = DESCRIPTOR.message_types_by_name['ChatMessageGetResponse']
_CHATDELETIONREQUEST = DESCRIPTOR.message_types_by_name['ChatDeletionRequest']
_CHATDELETIONRESPONSE = DESCRIPTOR.message_types_by_name['ChatDeletionResponse']
_CHATUPDATEREQUEST = DESCRIPTOR.message_types_by_name['ChatUpdateRequest']
_CHATUPDATERESPONSE = DESCRIPTOR.message_types_by_name['ChatUpdateResponse']
_CHATLISTREQUEST = DESCRIPTOR.message_types_by_name['ChatListRequest']
_CHATLISTRESPONSE = DESCRIPTOR.message_types_by_name['ChatListResponse']
_CHATSTARREQUEST = DESCRIPTOR.message_types_by_name['ChatStarRequest']
_CHATSTARRESPONSE = DESCRIPTOR.message_types_by_name['ChatStarResponse']
_COMPLETIONRESPONSE = DESCRIPTOR.message_types_by_name['CompletionResponse']
_BASEPAYLOAD = DESCRIPTOR.message_types_by_name['BasePayload']
_CHATCOMPLETIONREQUEST = DESCRIPTOR.message_types_by_name['ChatCompletionRequest']
_CHATSTOPCOMPLETIONREQUEST = DESCRIPTOR.message_types_by_name['ChatStopCompletionRequest']
_CHATSTOPCOMPLETIONRESPONSE = DESCRIPTOR.message_types_by_name['ChatStopCompletionResponse']
_CHATCOMPLETIONRESPONSE = DESCRIPTOR.message_types_by_name['ChatCompletionResponse']
MessageResponseError = _reflection.GeneratedProtocolMessageType('MessageResponseError', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGERESPONSEERROR,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageResponseError)
  })
_sym_db.RegisterMessage(MessageResponseError)

Message = _reflection.GeneratedProtocolMessageType('Message', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.Message)
  })
_sym_db.RegisterMessage(Message)

Messages = _reflection.GeneratedProtocolMessageType('Messages', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGES,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.Messages)
  })
_sym_db.RegisterMessage(Messages)

MessageDeletionRequest = _reflection.GeneratedProtocolMessageType('MessageDeletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEDELETIONREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageDeletionRequest)
  })
_sym_db.RegisterMessage(MessageDeletionRequest)

MessageDeletionResponse = _reflection.GeneratedProtocolMessageType('MessageDeletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGEDELETIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageDeletionResponse)
  })
_sym_db.RegisterMessage(MessageDeletionResponse)

MessageRatinResponseError = _reflection.GeneratedProtocolMessageType('MessageRatinResponseError', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGERATINRESPONSEERROR,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageRatinResponseError)
  })
_sym_db.RegisterMessage(MessageRatinResponseError)

MessageRating = _reflection.GeneratedProtocolMessageType('MessageRating', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGERATING,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageRating)
  })
_sym_db.RegisterMessage(MessageRating)

MessageRatingCreationRequest = _reflection.GeneratedProtocolMessageType('MessageRatingCreationRequest', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGERATINGCREATIONREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageRatingCreationRequest)
  })
_sym_db.RegisterMessage(MessageRatingCreationRequest)

MessageRatingCreationResponse = _reflection.GeneratedProtocolMessageType('MessageRatingCreationResponse', (_message.Message,), {
  'DESCRIPTOR' : _MESSAGERATINGCREATIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.MessageRatingCreationResponse)
  })
_sym_db.RegisterMessage(MessageRatingCreationResponse)

Chat = _reflection.GeneratedProtocolMessageType('Chat', (_message.Message,), {
  'DESCRIPTOR' : _CHAT,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.Chat)
  })
_sym_db.RegisterMessage(Chat)

ChatMessages = _reflection.GeneratedProtocolMessageType('ChatMessages', (_message.Message,), {

  'MessagesEntry' : _reflection.GeneratedProtocolMessageType('MessagesEntry', (_message.Message,), {
    'DESCRIPTOR' : _CHATMESSAGES_MESSAGESENTRY,
    '__module__' : 'chat_pb2'
    # @@protoc_insertion_point(class_scope:chat.ChatMessages.MessagesEntry)
    })
  ,
  'DESCRIPTOR' : _CHATMESSAGES,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatMessages)
  })
_sym_db.RegisterMessage(ChatMessages)
_sym_db.RegisterMessage(ChatMessages.MessagesEntry)

ChatResponseError = _reflection.GeneratedProtocolMessageType('ChatResponseError', (_message.Message,), {
  'DESCRIPTOR' : _CHATRESPONSEERROR,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatResponseError)
  })
_sym_db.RegisterMessage(ChatResponseError)

ChatCreationRequest = _reflection.GeneratedProtocolMessageType('ChatCreationRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATCREATIONREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatCreationRequest)
  })
_sym_db.RegisterMessage(ChatCreationRequest)

ChatCreationResponse = _reflection.GeneratedProtocolMessageType('ChatCreationResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATCREATIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatCreationResponse)
  })
_sym_db.RegisterMessage(ChatCreationResponse)

ChatGetRequest = _reflection.GeneratedProtocolMessageType('ChatGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATGETREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatGetRequest)
  })
_sym_db.RegisterMessage(ChatGetRequest)

ChatGetResponse = _reflection.GeneratedProtocolMessageType('ChatGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATGETRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatGetResponse)
  })
_sym_db.RegisterMessage(ChatGetResponse)

ChatMessageGetRequest = _reflection.GeneratedProtocolMessageType('ChatMessageGetRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATMESSAGEGETREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatMessageGetRequest)
  })
_sym_db.RegisterMessage(ChatMessageGetRequest)

ChatMessageGetResponse = _reflection.GeneratedProtocolMessageType('ChatMessageGetResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATMESSAGEGETRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatMessageGetResponse)
  })
_sym_db.RegisterMessage(ChatMessageGetResponse)

ChatDeletionRequest = _reflection.GeneratedProtocolMessageType('ChatDeletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATDELETIONREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatDeletionRequest)
  })
_sym_db.RegisterMessage(ChatDeletionRequest)

ChatDeletionResponse = _reflection.GeneratedProtocolMessageType('ChatDeletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATDELETIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatDeletionResponse)
  })
_sym_db.RegisterMessage(ChatDeletionResponse)

ChatUpdateRequest = _reflection.GeneratedProtocolMessageType('ChatUpdateRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATUPDATEREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatUpdateRequest)
  })
_sym_db.RegisterMessage(ChatUpdateRequest)

ChatUpdateResponse = _reflection.GeneratedProtocolMessageType('ChatUpdateResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATUPDATERESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatUpdateResponse)
  })
_sym_db.RegisterMessage(ChatUpdateResponse)

ChatListRequest = _reflection.GeneratedProtocolMessageType('ChatListRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATLISTREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatListRequest)
  })
_sym_db.RegisterMessage(ChatListRequest)

ChatListResponse = _reflection.GeneratedProtocolMessageType('ChatListResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATLISTRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatListResponse)
  })
_sym_db.RegisterMessage(ChatListResponse)

ChatStarRequest = _reflection.GeneratedProtocolMessageType('ChatStarRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATSTARREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatStarRequest)
  })
_sym_db.RegisterMessage(ChatStarRequest)

ChatStarResponse = _reflection.GeneratedProtocolMessageType('ChatStarResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATSTARRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatStarResponse)
  })
_sym_db.RegisterMessage(ChatStarResponse)

CompletionResponse = _reflection.GeneratedProtocolMessageType('CompletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _COMPLETIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.CompletionResponse)
  })
_sym_db.RegisterMessage(CompletionResponse)

BasePayload = _reflection.GeneratedProtocolMessageType('BasePayload', (_message.Message,), {
  'DESCRIPTOR' : _BASEPAYLOAD,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.BasePayload)
  })
_sym_db.RegisterMessage(BasePayload)

ChatCompletionRequest = _reflection.GeneratedProtocolMessageType('ChatCompletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATCOMPLETIONREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatCompletionRequest)
  })
_sym_db.RegisterMessage(ChatCompletionRequest)

ChatStopCompletionRequest = _reflection.GeneratedProtocolMessageType('ChatStopCompletionRequest', (_message.Message,), {
  'DESCRIPTOR' : _CHATSTOPCOMPLETIONREQUEST,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatStopCompletionRequest)
  })
_sym_db.RegisterMessage(ChatStopCompletionRequest)

ChatStopCompletionResponse = _reflection.GeneratedProtocolMessageType('ChatStopCompletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATSTOPCOMPLETIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatStopCompletionResponse)
  })
_sym_db.RegisterMessage(ChatStopCompletionResponse)

ChatCompletionResponse = _reflection.GeneratedProtocolMessageType('ChatCompletionResponse', (_message.Message,), {
  'DESCRIPTOR' : _CHATCOMPLETIONRESPONSE,
  '__module__' : 'chat_pb2'
  # @@protoc_insertion_point(class_scope:chat.ChatCompletionResponse)
  })
_sym_db.RegisterMessage(ChatCompletionResponse)

_CHATSERVICE = DESCRIPTOR.services_by_name['ChatService']
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  DESCRIPTOR._serialized_options = b'Z+github.com/jupyter-naas/naas-models/go/chat'
  _MESSAGE.fields_by_name['created_at']._options = None
  _MESSAGE.fields_by_name['created_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _MESSAGE.fields_by_name['message_type']._options = None
  _MESSAGE.fields_by_name['message_type']._serialized_options = b'\372B\005r\003\320\001\001'
  _MESSAGE.fields_by_name['message_language']._options = None
  _MESSAGE.fields_by_name['message_language']._serialized_options = b'\372B\005r\003\320\001\001'
  _MESSAGE.fields_by_name['deleted_at']._options = None
  _MESSAGE.fields_by_name['deleted_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _MESSAGE.fields_by_name['archived_at']._options = None
  _MESSAGE.fields_by_name['archived_at']._serialized_options = b'\372B\005r\003\320\001\001'
  _MESSAGERATING.fields_by_name['rating']._options = None
  _MESSAGERATING.fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _MESSAGERATINGCREATIONREQUEST.fields_by_name['rating']._options = None
  _MESSAGERATINGCREATIONREQUEST.fields_by_name['rating']._serialized_options = b'\372B\027r\0252\020^(LIKE|DISLIKE)$\320\001\000'
  _CHATMESSAGES_MESSAGESENTRY._options = None
  _CHATMESSAGES_MESSAGESENTRY._serialized_options = b'8\001'
  _MESSAGETYPE._serialized_start=4490
  _MESSAGETYPE._serialized_end=4549
  _MESSAGEERROR._serialized_start=4552
  _MESSAGEERROR._serialized_end=4692
  _COMPLETIONSTATUS._serialized_start=4694
  _COMPLETIONSTATUS._serialized_end=4752
  _CHATERROR._serialized_start=4755
  _CHATERROR._serialized_end=5008
  _MESSAGERESPONSEERROR._serialized_start=67
  _MESSAGERESPONSEERROR._serialized_end=235
  _MESSAGE._serialized_start=238
  _MESSAGE._serialized_end=834
  _MESSAGES._serialized_start=836
  _MESSAGES._serialized_end=879
  _MESSAGEDELETIONREQUEST._serialized_start=881
  _MESSAGEDELETIONREQUEST._serialized_end=963
  _MESSAGEDELETIONRESPONSE._serialized_start=965
  _MESSAGEDELETIONRESPONSE._serialized_end=1040
  _MESSAGERATINRESPONSEERROR._serialized_start=1043
  _MESSAGERATINRESPONSEERROR._serialized_end=1216
  _MESSAGERATING._serialized_start=1219
  _MESSAGERATING._serialized_end=1458
  _MESSAGERATINGCREATIONREQUEST._serialized_start=1461
  _MESSAGERATINGCREATIONREQUEST._serialized_end=1641
  _MESSAGERATINGCREATIONRESPONSE._serialized_start=1644
  _MESSAGERATINGCREATIONRESPONSE._serialized_end=1807
  _CHAT._serialized_start=1810
  _CHAT._serialized_end=2120
  _CHATMESSAGES._serialized_start=2123
  _CHATMESSAGES._serialized_end=2254
  _CHATMESSAGES_MESSAGESENTRY._serialized_start=2191
  _CHATMESSAGES_MESSAGESENTRY._serialized_end=2254
  _CHATRESPONSEERROR._serialized_start=2257
  _CHATRESPONSEERROR._serialized_end=2419
  _CHATCREATIONREQUEST._serialized_start=2421
  _CHATCREATIONREQUEST._serialized_end=2532
  _CHATCREATIONRESPONSE._serialized_start=2534
  _CHATCREATIONRESPONSE._serialized_end=2651
  _CHATGETREQUEST._serialized_start=2653
  _CHATGETREQUEST._serialized_end=2693
  _CHATGETRESPONSE._serialized_start=2695
  _CHATGETRESPONSE._serialized_end=2807
  _CHATMESSAGEGETREQUEST._serialized_start=2809
  _CHATMESSAGEGETREQUEST._serialized_end=2856
  _CHATMESSAGEGETRESPONSE._serialized_start=2859
  _CHATMESSAGEGETRESPONSE._serialized_end=2994
  _CHATDELETIONREQUEST._serialized_start=2996
  _CHATDELETIONREQUEST._serialized_end=3041
  _CHATDELETIONRESPONSE._serialized_start=3043
  _CHATDELETIONRESPONSE._serialized_end=3120
  _CHATUPDATEREQUEST._serialized_start=3122
  _CHATUPDATEREQUEST._serialized_end=3193
  _CHATUPDATERESPONSE._serialized_start=3195
  _CHATUPDATERESPONSE._serialized_end=3310
  _CHATLISTREQUEST._serialized_start=3312
  _CHATLISTREQUEST._serialized_end=3409
  _CHATLISTRESPONSE._serialized_start=3411
  _CHATLISTRESPONSE._serialized_end=3510
  _CHATSTARREQUEST._serialized_start=3512
  _CHATSTARREQUEST._serialized_end=3581
  _CHATSTARRESPONSE._serialized_start=3583
  _CHATSTARRESPONSE._serialized_end=3686
  _COMPLETIONRESPONSE._serialized_start=3689
  _COMPLETIONRESPONSE._serialized_end=3982
  _BASEPAYLOAD._serialized_start=3984
  _BASEPAYLOAD._serialized_end=4083
  _CHATCOMPLETIONREQUEST._serialized_start=4085
  _CHATCOMPLETIONREQUEST._serialized_end=4202
  _CHATSTOPCOMPLETIONREQUEST._serialized_start=4204
  _CHATSTOPCOMPLETIONREQUEST._serialized_end=4255
  _CHATSTOPCOMPLETIONRESPONSE._serialized_start=4257
  _CHATSTOPCOMPLETIONRESPONSE._serialized_end=4340
  _CHATCOMPLETIONRESPONSE._serialized_start=4343
  _CHATCOMPLETIONRESPONSE._serialized_end=4488
  _CHATSERVICE._serialized_start=5011
  _CHATSERVICE._serialized_end=5389
# @@protoc_insertion_point(module_scope)
